# pylint: disable=line-too-long,useless-suppression
# coding: utf-8

# -------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
# --------------------------------------------------------------------------
import unittest
import pytest

import azure.mgmt.monitor
from devtools_testutils import AzureMgmtRecordedTestCase, RandomNameResourceGroupPreparer, recorded_by_proxy
from azure.core.exceptions import HttpResponseError

AZURE_LOCATION = "eastus"


@pytest.mark.live_test_only
class TestMgmtMonitor(AzureMgmtRecordedTestCase):

    def setup_method(self, method):
        self.mgmt_client = self.create_mgmt_client(azure.mgmt.monitor.MonitorManagementClient)

    @RandomNameResourceGroupPreparer(location=AZURE_LOCATION)
    @recorded_by_proxy
    def test_monitor_skip_url(self, resource_group):
        resource_uri = "/subscriptions/1234abcd-1234-abcd-5678-1234abcd5678/resourceGroups/my-test-rg/providers/Microsoft.Sql/servers/mytestserver/databases/{Object.value}"

        with pytest.raises(HttpResponseError):
            self.mgmt_client.metrics.list(resource_uri=resource_uri)


# ------------------------------------------------------------------------------
if __name__ == "__main__":
    unittest.main()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from copy import deepcopy
import sys
from typing import Any, Optional, TYPE_CHECKING, cast

from azure.core.pipeline import policies
from azure.core.rest import HttpRequest, HttpResponse
from azure.core.settings import settings
from azure.mgmt.core import ARMPipelineClient
from azure.mgmt.core.policies import ARMAutoResourceProviderRegistrationPolicy
from azure.mgmt.core.tools import get_arm_endpoints

from ._configuration import MonitorManagementClientConfiguration
from ._utils.serialization import Deserializer, Serializer
from .operations import (
    ActionGroupsOperations,
    ActivityLogAlertsOperations,
    ActivityLogsOperations,
    AlertRuleIncidentsOperations,
    AutoscaleSettingsOperations,
    BaselinesOperations,
    DataCollectionEndpointsOperations,
    DataCollectionRuleAssociationsOperations,
    DataCollectionRulesOperations,
    EventCategoriesOperations,
    LogProfilesOperations,
    MetricAlertsOperations,
    MetricAlertsStatusOperations,
    MetricDefinitionsOperations,
    MetricNamespacesOperations,
    MetricsOperations,
    PredictiveMetricOperations,
    PrivateEndpointConnectionsOperations,
    PrivateLinkResourcesOperations,
    PrivateLinkScopeOperationStatusOperations,
    PrivateLinkScopedResourcesOperations,
    PrivateLinkScopesOperations,
    ScheduledQueryRuleOperations,
    ScheduledQueryRulesOperations,
    ServiceDiagnosticSettingsOperations,
    TenantActivityLogsOperations,
)

if sys.version_info >= (3, 11):
    from typing import Self
else:
    from typing_extensions import Self  # type: ignore

if TYPE_CHECKING:
    from azure.core import AzureClouds
    from azure.core.credentials import TokenCredential


class MonitorManagementClient:  # pylint: disable=client-accepts-api-version-keyword,too-many-instance-attributes
    """MonitorManagementClient.

    :ivar private_link_resources: PrivateLinkResourcesOperations operations
    :vartype private_link_resources: azure.mgmt.monitor.operations.PrivateLinkResourcesOperations
    :ivar private_endpoint_connections: PrivateEndpointConnectionsOperations operations
    :vartype private_endpoint_connections:
     azure.mgmt.monitor.operations.PrivateEndpointConnectionsOperations
    :ivar data_collection_endpoints: DataCollectionEndpointsOperations operations
    :vartype data_collection_endpoints:
     azure.mgmt.monitor.operations.DataCollectionEndpointsOperations
    :ivar scheduled_query_rule: ScheduledQueryRuleOperations operations
    :vartype scheduled_query_rule: azure.mgmt.monitor.operations.ScheduledQueryRuleOperations
    :ivar data_collection_rule_associations: DataCollectionRuleAssociationsOperations operations
    :vartype data_collection_rule_associations:
     azure.mgmt.monitor.operations.DataCollectionRuleAssociationsOperations
    :ivar data_collection_rules: DataCollectionRulesOperations operations
    :vartype data_collection_rules: azure.mgmt.monitor.operations.DataCollectionRulesOperations
    :ivar private_link_scopes: PrivateLinkScopesOperations operations
    :vartype private_link_scopes: azure.mgmt.monitor.operations.PrivateLinkScopesOperations
    :ivar private_link_scoped_resources: PrivateLinkScopedResourcesOperations operations
    :vartype private_link_scoped_resources:
     azure.mgmt.monitor.operations.PrivateLinkScopedResourcesOperations
    :ivar private_link_scope_operation_status: PrivateLinkScopeOperationStatusOperations operations
    :vartype private_link_scope_operation_status:
     azure.mgmt.monitor.operations.PrivateLinkScopeOperationStatusOperations
    :ivar autoscale_settings: AutoscaleSettingsOperations operations
    :vartype autoscale_settings: azure.mgmt.monitor.operations.AutoscaleSettingsOperations
    :ivar predictive_metric: PredictiveMetricOperations operations
    :vartype predictive_metric: azure.mgmt.monitor.operations.PredictiveMetricOperations
    :ivar activity_logs: ActivityLogsOperations operations
    :vartype activity_logs: azure.mgmt.monitor.operations.ActivityLogsOperations
    :ivar event_categories: EventCategoriesOperations operations
    :vartype event_categories: azure.mgmt.monitor.operations.EventCategoriesOperations
    :ivar tenant_activity_logs: TenantActivityLogsOperations operations
    :vartype tenant_activity_logs: azure.mgmt.monitor.operations.TenantActivityLogsOperations
    :ivar metric_definitions: MetricDefinitionsOperations operations
    :vartype metric_definitions: azure.mgmt.monitor.operations.MetricDefinitionsOperations
    :ivar metric_namespaces: MetricNamespacesOperations operations
    :vartype metric_namespaces: azure.mgmt.monitor.operations.MetricNamespacesOperations
    :ivar metrics: MetricsOperations operations
    :vartype metrics: azure.mgmt.monitor.operations.MetricsOperations
    :ivar service_diagnostic_settings: ServiceDiagnosticSettingsOperations operations
    :vartype service_diagnostic_settings:
     azure.mgmt.monitor.operations.ServiceDiagnosticSettingsOperations
    :ivar alert_rule_incidents: AlertRuleIncidentsOperations operations
    :vartype alert_rule_incidents: azure.mgmt.monitor.operations.AlertRuleIncidentsOperations
    :ivar log_profiles: LogProfilesOperations operations
    :vartype log_profiles: azure.mgmt.monitor.operations.LogProfilesOperations
    :ivar activity_log_alerts: ActivityLogAlertsOperations operations
    :vartype activity_log_alerts: azure.mgmt.monitor.operations.ActivityLogAlertsOperations
    :ivar metric_alerts: MetricAlertsOperations operations
    :vartype metric_alerts: azure.mgmt.monitor.operations.MetricAlertsOperations
    :ivar metric_alerts_status: MetricAlertsStatusOperations operations
    :vartype metric_alerts_status: azure.mgmt.monitor.operations.MetricAlertsStatusOperations
    :ivar scheduled_query_rules: ScheduledQueryRulesOperations operations
    :vartype scheduled_query_rules: azure.mgmt.monitor.operations.ScheduledQueryRulesOperations
    :ivar baselines: BaselinesOperations operations
    :vartype baselines: azure.mgmt.monitor.operations.BaselinesOperations
    :ivar action_groups: ActionGroupsOperations operations
    :vartype action_groups: azure.mgmt.monitor.operations.ActionGroupsOperations
    :param credential: Credential used to authenticate requests to the service. Required.
    :type credential: ~azure.core.credentials.TokenCredential
    :param subscription_id: The ID of the target subscription. The value must be an UUID. Required.
    :type subscription_id: str
    :param base_url: Service host. Default value is None.
    :type base_url: str
    :keyword cloud_setting: The cloud setting for which to get the ARM endpoint. Default value is
     None.
    :paramtype cloud_setting: ~azure.core.AzureClouds
    :keyword int polling_interval: Default waiting time between two polls for LRO operations if no
     Retry-After header is present.
    """

    def __init__(
        self,
        credential: "TokenCredential",
        subscription_id: str,
        base_url: Optional[str] = None,
        *,
        cloud_setting: Optional["AzureClouds"] = None,
        **kwargs: Any
    ) -> None:
        _endpoint = "{endpoint}"
        _cloud = cloud_setting or settings.current.azure_cloud  # type: ignore
        _endpoints = get_arm_endpoints(_cloud)
        if not base_url:
            base_url = _endpoints["resource_manager"]
        credential_scopes = kwargs.pop("credential_scopes", _endpoints["credential_scopes"])
        self._config = MonitorManagementClientConfiguration(
            credential=credential,
            subscription_id=subscription_id,
            base_url=cast(str, base_url),
            cloud_setting=cloud_setting,
            credential_scopes=credential_scopes,
            **kwargs
        )

        _policies = kwargs.pop("policies", None)
        if _policies is None:
            _policies = [
                policies.RequestIdPolicy(**kwargs),
                self._config.headers_policy,
                self._config.user_agent_policy,
                self._config.proxy_policy,
                policies.ContentDecodePolicy(**kwargs),
                ARMAutoResourceProviderRegistrationPolicy(),
                self._config.redirect_policy,
                self._config.retry_policy,
                self._config.authentication_policy,
                self._config.custom_hook_policy,
                self._config.logging_policy,
                policies.DistributedTracingPolicy(**kwargs),
                policies.SensitiveHeaderCleanupPolicy(**kwargs) if self._config.redirect_policy else None,
                self._config.http_logging_policy,
            ]
        self._client: ARMPipelineClient = ARMPipelineClient(base_url=cast(str, _endpoint), policies=_policies, **kwargs)

        self._serialize = Serializer()
        self._deserialize = Deserializer()
        self._serialize.client_side_validation = False
        self.private_link_resources = PrivateLinkResourcesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_endpoint_connections = PrivateEndpointConnectionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.data_collection_endpoints = DataCollectionEndpointsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.scheduled_query_rule = ScheduledQueryRuleOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.data_collection_rule_associations = DataCollectionRuleAssociationsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.data_collection_rules = DataCollectionRulesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_link_scopes = PrivateLinkScopesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_link_scoped_resources = PrivateLinkScopedResourcesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.private_link_scope_operation_status = PrivateLinkScopeOperationStatusOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.autoscale_settings = AutoscaleSettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.predictive_metric = PredictiveMetricOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.activity_logs = ActivityLogsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.event_categories = EventCategoriesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.tenant_activity_logs = TenantActivityLogsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.metric_definitions = MetricDefinitionsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.metric_namespaces = MetricNamespacesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.metrics = MetricsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.service_diagnostic_settings = ServiceDiagnosticSettingsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.alert_rule_incidents = AlertRuleIncidentsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.log_profiles = LogProfilesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.activity_log_alerts = ActivityLogAlertsOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.metric_alerts = MetricAlertsOperations(self._client, self._config, self._serialize, self._deserialize)
        self.metric_alerts_status = MetricAlertsStatusOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.scheduled_query_rules = ScheduledQueryRulesOperations(
            self._client, self._config, self._serialize, self._deserialize
        )
        self.baselines = BaselinesOperations(self._client, self._config, self._serialize, self._deserialize)
        self.action_groups = ActionGroupsOperations(self._client, self._config, self._serialize, self._deserialize)

    def send_request(self, request: HttpRequest, *, stream: bool = False, **kwargs: Any) -> HttpResponse:
        """Runs the network request through the client's chained policies.

        >>> from azure.core.rest import HttpRequest
        >>> request = HttpRequest("GET", "https://www.example.org/")
        <HttpRequest [GET], url: 'https://www.example.org/'>
        >>> response = client.send_request(request)
        <HttpResponse: 200 OK>

        For more information on this code flow, see https://aka.ms/azsdk/dpcodegen/python/send_request

        :param request: The network request you want to make. Required.
        :type request: ~azure.core.rest.HttpRequest
        :keyword bool stream: Whether the response payload will be streamed. Defaults to False.
        :return: The response of your network call. Does not do error handling on your response.
        :rtype: ~azure.core.rest.HttpResponse
        """

        request_copy = deepcopy(request)
        path_format_arguments = {
            "endpoint": self._serialize.url("self._config.base_url", self._config.base_url, "str", skip_quote=True),
        }

        request_copy.url = self._client.format_url(request_copy.url, **path_format_arguments)
        return self._client.send_request(request_copy, stream=stream, **kwargs)  # type: ignore

    def close(self) -> None:
        self._client.close()

    def __enter__(self) -> Self:
        self._client.__enter__()
        return self

    def __exit__(self, *exc_details: Any) -> None:
        self._client.__exit__(*exc_details)



# pylint: disable=too-many-lines
# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------

from enum import Enum
from azure.core import CaseInsensitiveEnumMeta


class AccessMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Access mode types."""

    OPEN = "Open"
    """Open."""
    PRIVATE_ONLY = "PrivateOnly"
    """PrivateOnly."""


class AccessRuleDirection(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Direction of Access Rule."""

    INBOUND = "Inbound"
    """Applies to inbound network traffic to the secured resources."""
    OUTBOUND = "Outbound"
    """Applies to outbound network traffic from the secured resources."""


class AggregationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The aggregation type of the metric."""

    NONE = "None"
    """None."""
    AVERAGE = "Average"
    """Average."""
    COUNT = "Count"
    """Count."""
    MINIMUM = "Minimum"
    """Minimum."""
    MAXIMUM = "Maximum"
    """Maximum."""
    TOTAL = "Total"
    """Total."""


class AggregationTypeEnum(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The criteria time aggregation types. Previously undocumented values might be returned."""

    AVERAGE = "Average"
    """Average."""
    COUNT = "Count"
    """Count."""
    MINIMUM = "Minimum"
    """Minimum."""
    MAXIMUM = "Maximum"
    """Maximum."""
    TOTAL = "Total"
    """Total."""


class AlertSeverity(int, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Severity of the alert. Should be an integer between [0-4]. Value of 0 is severest. Relevant and
    required only for rules of the kind LogAlert.
    """

    ZERO = 0
    """0."""
    ONE = 1
    """1."""
    TWO = 2
    """2."""
    THREE = 3
    """3."""
    FOUR = 4
    """4."""


class BaselineSensitivity(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the sensitivity of the baseline."""

    LOW = "Low"
    """Low."""
    MEDIUM = "Medium"
    """Medium."""
    HIGH = "High"
    """High."""


class ComparisonOperationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the operator that is used to compare the metric data and the threshold."""

    EQUALS = "Equals"
    """Equals."""
    NOT_EQUALS = "NotEquals"
    """NotEquals."""
    GREATER_THAN = "GreaterThan"
    """GreaterThan."""
    GREATER_THAN_OR_EQUAL = "GreaterThanOrEqual"
    """GreaterThanOrEqual."""
    LESS_THAN = "LessThan"
    """LessThan."""
    LESS_THAN_OR_EQUAL = "LessThanOrEqual"
    """LessThanOrEqual."""


class ConditionOperator(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The criteria operator. Relevant and required only for rules of the kind LogAlert."""

    EQUALS = "Equals"
    """Equals."""
    GREATER_THAN = "GreaterThan"
    """GreaterThan."""
    GREATER_THAN_OR_EQUAL = "GreaterThanOrEqual"
    """GreaterThanOrEqual."""
    LESS_THAN = "LessThan"
    """LessThan."""
    LESS_THAN_OR_EQUAL = "LessThanOrEqual"
    """LessThanOrEqual."""
    GREATER_OR_LESS_THAN = "GreaterOrLessThan"
    """GreaterOrLessThan."""


class CreatedByType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of entity that created the resource."""

    USER = "User"
    """The entity was created by a user."""
    APPLICATION = "Application"
    """The entity was created by an application."""
    MANAGED_IDENTITY = "ManagedIdentity"
    """The entity was created by a managed identity."""
    KEY = "Key"
    """The entity was created by a key."""


class CriterionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the type of threshold criteria. Previously undocumented values might be returned."""

    STATIC_THRESHOLD_CRITERION = "StaticThresholdCriterion"
    """StaticThresholdCriterion."""
    DYNAMIC_THRESHOLD_CRITERION = "DynamicThresholdCriterion"
    """DynamicThresholdCriterion."""


class DimensionOperator(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Operator for dimension values."""

    INCLUDE = "Include"
    """Include."""
    EXCLUDE = "Exclude"
    """Exclude."""


class DynamicThresholdOperator(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The operator used to compare the metric value against the threshold. Previously undocumented
    values might be returned.
    """

    GREATER_THAN = "GreaterThan"
    """GreaterThan."""
    LESS_THAN = "LessThan"
    """LessThan."""
    GREATER_OR_LESS_THAN = "GreaterOrLessThan"
    """GreaterOrLessThan."""


class DynamicThresholdSensitivity(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The extent of deviation required to trigger an alert. This will affect how tight the threshold
    is to the metric series pattern. Previously undocumented values might be returned.
    """

    LOW = "Low"
    """Low."""
    MEDIUM = "Medium"
    """Medium."""
    HIGH = "High"
    """High."""


class EventLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the event level."""

    CRITICAL = "Critical"
    """Critical."""
    ERROR = "Error"
    """Error."""
    WARNING = "Warning"
    """Warning."""
    INFORMATIONAL = "Informational"
    """Informational."""
    VERBOSE = "Verbose"
    """Verbose."""


class IdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of managed service identity."""

    SYSTEM_ASSIGNED = "SystemAssigned"
    """SystemAssigned."""
    USER_ASSIGNED = "UserAssigned"
    """UserAssigned."""
    NONE = "None"
    """None."""


class IncidentManagementService(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The incident management service type."""

    ICM = "Icm"
    """Icm."""


class IssueType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of issue."""

    UNKNOWN = "Unknown"
    """Unknown issue type."""
    CONFIGURATION_PROPAGATION_FAILURE = "ConfigurationPropagationFailure"
    """An error occurred while applying the network security perimeter (NSP) configuration."""
    MISSING_PERIMETER_CONFIGURATION = "MissingPerimeterConfiguration"
    """A network connectivity issue is happening on the resource which could be addressed either by
    adding new resources to the network security perimeter (NSP) or by modifying access rules."""
    MISSING_IDENTITY_CONFIGURATION = "MissingIdentityConfiguration"
    """An managed identity hasn't been associated with the resource. The resource will still be able
    to validate inbound traffic from the network security perimeter (NSP) or matching inbound
    access rules, but it won't be able to perform outbound access as a member of the NSP."""


class Kind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Indicates the type of scheduled query rule. The default is LogAlert."""

    LOG_ALERT = "LogAlert"
    """LogAlert."""
    SIMPLE_LOG_ALERT = "SimpleLogAlert"
    """SimpleLogAlert."""
    LOG_TO_METRIC = "LogToMetric"
    """LogToMetric."""


class KnownAgentSettingName(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The name of the setting. Must be part of the list of supported settings."""

    MAX_DISK_QUOTA_IN_MB = "MaxDiskQuotaInMB"
    """MaxDiskQuotaInMB."""
    USE_TIME_RECEIVED_FOR_FORWARDED_EVENTS = "UseTimeReceivedForForwardedEvents"
    """UseTimeReceivedForForwardedEvents."""
    TAGS = "Tags"
    """Tags."""


class KnownColumnDefinitionType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of the column data."""

    STRING = "string"
    """string."""
    INT = "int"
    """int."""
    LONG = "long"
    """long."""
    REAL = "real"
    """real."""
    BOOLEAN = "boolean"
    """boolean."""
    DATETIME = "datetime"
    """datetime."""
    DYNAMIC = "dynamic"
    """dynamic."""


class KnownDataCollectionEndpointProvisioningState(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """The resource provisioning state. This property is READ-ONLY."""

    CREATING = "Creating"
    """Creating."""
    UPDATING = "Updating"
    """Updating."""
    DELETING = "Deleting"
    """Deleting."""
    SUCCEEDED = "Succeeded"
    """Succeeded."""
    CANCELED = "Canceled"
    """Canceled."""
    FAILED = "Failed"
    """Failed."""


class KnownDataCollectionEndpointResourceKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of the resource."""

    LINUX = "Linux"
    """Linux."""
    WINDOWS = "Windows"
    """Windows."""


class KnownDataCollectionRuleAssociationProvisioningState(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """The resource provisioning state."""

    CREATING = "Creating"
    """Creating."""
    UPDATING = "Updating"
    """Updating."""
    DELETING = "Deleting"
    """Deleting."""
    SUCCEEDED = "Succeeded"
    """Succeeded."""
    CANCELED = "Canceled"
    """Canceled."""
    FAILED = "Failed"
    """Failed."""


class KnownDataCollectionRuleProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The resource provisioning state."""

    CREATING = "Creating"
    """Creating."""
    UPDATING = "Updating"
    """Updating."""
    DELETING = "Deleting"
    """Deleting."""
    SUCCEEDED = "Succeeded"
    """Succeeded."""
    CANCELED = "Canceled"
    """Canceled."""
    FAILED = "Failed"
    """Failed."""


class KnownDataCollectionRuleResourceKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of the resource."""

    LINUX = "Linux"
    """Linux."""
    WINDOWS = "Windows"
    """Windows."""


class KnownDataFlowStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownDataFlowStreams."""

    MICROSOFT_EVENT = "Microsoft-Event"
    """Microsoft-Event."""
    MICROSOFT_INSIGHTS_METRICS = "Microsoft-InsightsMetrics"
    """Microsoft-InsightsMetrics."""
    MICROSOFT_PERF = "Microsoft-Perf"
    """Microsoft-Perf."""
    MICROSOFT_SYSLOG = "Microsoft-Syslog"
    """Microsoft-Syslog."""
    MICROSOFT_WINDOWS_EVENT = "Microsoft-WindowsEvent"
    """Microsoft-WindowsEvent."""


class KnownEtwProviderDataSourceLogLevel(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Minimal level of detail to be logged."""

    CRITICAL = "Critical"
    """Critical."""
    ERROR = "Error"
    """Error."""
    WARNING = "Warning"
    """Warning."""
    INFORMATIONAL = "Informational"
    """Informational."""
    VERBOSE = "Verbose"
    """Verbose."""


class KnownEtwProviderType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Provider type specification: By Manifest GUID or by Event Source name."""

    EVENT_SOURCE = "EventSource"
    """EventSource."""
    MANIFEST = "Manifest"
    """Manifest."""


class KnownExtensionDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownExtensionDataSourceStreams."""

    MICROSOFT_EVENT = "Microsoft-Event"
    """Microsoft-Event."""
    MICROSOFT_INSIGHTS_METRICS = "Microsoft-InsightsMetrics"
    """Microsoft-InsightsMetrics."""
    MICROSOFT_PERF = "Microsoft-Perf"
    """Microsoft-Perf."""
    MICROSOFT_SYSLOG = "Microsoft-Syslog"
    """Microsoft-Syslog."""
    MICROSOFT_WINDOWS_EVENT = "Microsoft-WindowsEvent"
    """Microsoft-WindowsEvent."""


class KnownLocationSpecProvisioningStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The resource provisioning state in this location."""

    CREATING = "Creating"
    """Creating."""
    UPDATING = "Updating"
    """Updating."""
    DELETING = "Deleting"
    """Deleting."""
    SUCCEEDED = "Succeeded"
    """Succeeded."""
    CANCELED = "Canceled"
    """Canceled."""
    FAILED = "Failed"
    """Failed."""


class KnownLogFilesDataSourceFormat(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The data format of the log files."""

    JSON = "json"
    """json."""
    TEXT = "text"
    """text."""


class KnownLogFileTextSettingsRecordStartTimestampFormat(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """One of the supported timestamp formats."""

    ISO8601 = "ISO 8601"
    """ISO 8601."""
    YYYY_MM_DD_HH_MM_SS = "YYYY-MM-DD HH:MM:SS"
    """YYYY-MM-DD HH:MM:SS."""
    M_D_YYYY_HH_MM_SS_AM_PM = "M/D/YYYY HH:MM:SS AM/PM"
    """M/D/YYYY HH:MM:SS AM/PM."""
    MON_DD_YYYY_HH_MM_SS = "Mon DD, YYYY HH:MM:SS"
    """Mon DD, YYYY HH:MM:SS."""
    YY_M_MDD_HH_MM_SS = "yyMMdd HH:mm:ss"
    """yyMMdd HH:mm:ss."""
    DD_M_MYY_HH_MM_SS = "ddMMyy HH:mm:ss"
    """ddMMyy HH:mm:ss."""
    MMM_D_HH_MM_SS = "MMM d hh:mm:ss"
    """MMM d hh:mm:ss."""
    DD_MMM_YYYY_HH_MM_SS_ZZZ = "dd/MMM/yyyy:HH:mm:ss zzz"
    """dd/MMM/yyyy:HH:mm:ss zzz."""
    YYYY_MM_DD_THH_MM_SS_K = "yyyy-MM-ddTHH:mm:ssK"
    """yyyy-MM-ddTHH:mm:ssK."""


class KnownOtelLogsDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownOtelLogsDataSourceStreams."""

    MICROSOFT_O_TEL_LOGS = "Microsoft-OTel-Logs"
    """Microsoft-OTel-Logs."""


class KnownOtelLogsDirectDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownOtelLogsDirectDataSourceStreams."""

    MICROSOFT_O_TEL_LOGS = "Microsoft-OTel-Logs"
    """Microsoft-OTel-Logs."""


class KnownOtelTracesDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownOtelTracesDataSourceStreams."""

    MICROSOFT_O_TEL_TRACES_SPANS = "Microsoft-OTel-Traces-Spans"
    """Microsoft-OTel-Traces-Spans."""
    MICROSOFT_O_TEL_TRACES_EVENTS = "Microsoft-OTel-Traces-Events"
    """Microsoft-OTel-Traces-Events."""
    MICROSOFT_O_TEL_TRACES_RESOURCES = "Microsoft-OTel-Traces-Resources"
    """Microsoft-OTel-Traces-Resources."""


class KnownOtelTracesDirectDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownOtelTracesDirectDataSourceStreams."""

    MICROSOFT_O_TEL_TRACES_SPANS = "Microsoft-OTel-Traces-Spans"
    """Microsoft-OTel-Traces-Spans."""
    MICROSOFT_O_TEL_TRACES_EVENTS = "Microsoft-OTel-Traces-Events"
    """Microsoft-OTel-Traces-Events."""
    MICROSOFT_O_TEL_TRACES_RESOURCES = "Microsoft-OTel-Traces-Resources"
    """Microsoft-OTel-Traces-Resources."""


class KnownPerfCounterDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownPerfCounterDataSourceStreams."""

    MICROSOFT_PERF = "Microsoft-Perf"
    """Microsoft-Perf."""
    MICROSOFT_INSIGHTS_METRICS = "Microsoft-InsightsMetrics"
    """Microsoft-InsightsMetrics."""


class KnownPerformanceCountersOTelDataSourceStreams(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """Type of KnownPerformanceCountersOTelDataSourceStreams."""

    MICROSOFT_OTEL_PERF_METRICS = "Microsoft-OtelPerfMetrics"
    """Microsoft-OtelPerfMetrics."""


class KnownPrometheusForwarderDataSourceStreams(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """Type of KnownPrometheusForwarderDataSourceStreams."""

    MICROSOFT_PROMETHEUS_METRICS = "Microsoft-PrometheusMetrics"
    """Microsoft-PrometheusMetrics."""


class KnownPublicNetworkAccessOptions(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The configuration to set whether network access from public internet to the endpoints are
    allowed.
    """

    ENABLED = "Enabled"
    """Enabled."""
    DISABLED = "Disabled"
    """Disabled."""
    SECURED_BY_PERIMETER = "SecuredByPerimeter"
    """SecuredByPerimeter."""


class KnownStorageBlobLookupType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The type of lookup to perform on the blob."""

    STRING = "String"
    """String."""
    CIDR = "Cidr"
    """Cidr."""


class KnownSyslogDataSourceFacilityNames(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownSyslogDataSourceFacilityNames."""

    ASTERISK = "*"
    """
    
    *."""
    ALERT = "alert"
    """alert."""
    AUDIT = "audit"
    """audit."""
    AUTH = "auth"
    """auth."""
    AUTHPRIV = "authpriv"
    """authpriv."""
    CLOCK = "clock"
    """clock."""
    CRON = "cron"
    """cron."""
    DAEMON = "daemon"
    """daemon."""
    FTP = "ftp"
    """ftp."""
    KERN = "kern"
    """kern."""
    LOCAL0 = "local0"
    """local0."""
    LOCAL1 = "local1"
    """local1."""
    LOCAL2 = "local2"
    """local2."""
    LOCAL3 = "local3"
    """local3."""
    LOCAL4 = "local4"
    """local4."""
    LOCAL5 = "local5"
    """local5."""
    LOCAL6 = "local6"
    """local6."""
    LOCAL7 = "local7"
    """local7."""
    LPR = "lpr"
    """lpr."""
    MAIL = "mail"
    """mail."""
    MARK = "mark"
    """mark."""
    NEWS = "news"
    """news."""
    NOPRI = "nopri"
    """nopri."""
    NTP = "ntp"
    """ntp."""
    SYSLOG = "syslog"
    """syslog."""
    USER = "user"
    """user."""
    UUCP = "uucp"
    """uucp."""


class KnownSyslogDataSourceLogLevels(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownSyslogDataSourceLogLevels."""

    DEBUG = "Debug"
    """Debug."""
    INFO = "Info"
    """Info."""
    NOTICE = "Notice"
    """Notice."""
    WARNING = "Warning"
    """Warning."""
    ERROR = "Error"
    """Error."""
    CRITICAL = "Critical"
    """Critical."""
    ALERT = "Alert"
    """Alert."""
    EMERGENCY = "Emergency"
    """Emergency."""
    ASTERISK = "*"
    """
    
    *."""


class KnownSyslogDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownSyslogDataSourceStreams."""

    MICROSOFT_SYSLOG = "Microsoft-Syslog"
    """Microsoft-Syslog."""


class KnownWindowsEventLogDataSourceStreams(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of KnownWindowsEventLogDataSourceStreams."""

    MICROSOFT_WINDOWS_EVENT = "Microsoft-WindowsEvent"
    """Microsoft-WindowsEvent."""
    MICROSOFT_EVENT = "Microsoft-Event"
    """Microsoft-Event."""


class KnownWindowsFirewallLogsDataSourceProfileFilter(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """Type of KnownWindowsFirewallLogsDataSourceProfileFilter."""

    DOMAIN = "Domain"
    """Domain."""
    PRIVATE = "Private"
    """Private."""
    PUBLIC = "Public"
    """Public."""


class ManagedServiceIdentityType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of managed service identity (where both SystemAssigned and UserAssigned types are
    allowed).
    """

    NONE = "None"
    """No managed identity."""
    SYSTEM_ASSIGNED = "SystemAssigned"
    """System assigned managed identity."""
    USER_ASSIGNED = "UserAssigned"
    """User assigned managed identity."""
    SYSTEM_ASSIGNED_USER_ASSIGNED = "SystemAssigned,UserAssigned"
    """System and user assigned managed identity."""


class MetricAggregationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The aggregation type of the metric."""

    NONE = "None"
    """None."""
    AVERAGE = "Average"
    """Average."""
    COUNT = "Count"
    """Count."""
    MINIMUM = "Minimum"
    """Minimum."""
    MAXIMUM = "Maximum"
    """Maximum."""
    TOTAL = "Total"
    """Total."""


class MetricClass(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The class of the metric."""

    AVAILABILITY = "Availability"
    """Availability."""
    TRANSACTIONS = "Transactions"
    """Transactions."""
    ERRORS = "Errors"
    """Errors."""
    LATENCY = "Latency"
    """Latency."""
    SATURATION = "Saturation"
    """Saturation."""


class MetricResultType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Reduces the set of data collected. The syntax allowed depends on the operation. See the
    operation's description for details.
    """

    DATA = "Data"
    """Data."""
    METADATA = "Metadata"
    """Metadata."""


class MetricStatisticType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the metric statistic type. How the metrics from multiple instances are combined."""

    AVERAGE = "Average"
    """Average."""
    MIN = "Min"
    """Min."""
    MAX = "Max"
    """Max."""
    SUM = "Sum"
    """Sum."""
    COUNT = "Count"
    """Count."""


class MetricUnit(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The unit of the metric."""

    COUNT = "Count"
    """Unit of raw quantity."""
    BYTES = "Bytes"
    """Unit of memory in bytes."""
    SECONDS = "Seconds"
    """Unit of time in seconds."""
    COUNT_PER_SECOND = "CountPerSecond"
    """Rate unit of raw quantity per second."""
    BYTES_PER_SECOND = "BytesPerSecond"
    """Rate unit of memory in bytes per second."""
    PERCENT = "Percent"
    """Percentage unit."""
    MILLI_SECONDS = "MilliSeconds"
    """Unit of time in 1/1000th of a second."""
    BYTE_SECONDS = "ByteSeconds"
    """Unit of data transfer or storage. It is the size of the data in bytes multiplied by the time it
    takes to transfer or store the data in seconds."""
    UNSPECIFIED = "Unspecified"
    """No specified unit."""
    CORES = "Cores"
    """Unit of processing power."""
    MILLI_CORES = "MilliCores"
    """Unit of processing power in 1/1000th of a CPU core."""
    NANO_CORES = "NanoCores"
    """Unit of processing power in one billionth of a CPU core."""
    BITS_PER_SECOND = "BitsPerSecond"
    """Rate unit of binary digits per second."""


class NamespaceClassification(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Kind of namespace."""

    PLATFORM = "Platform"
    """Platform."""
    CUSTOM = "Custom"
    """Custom."""
    QOS = "Qos"
    """Qos."""


class NetworkSecurityPerimeterConfigurationProvisioningState(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """Provisioning state of a network security perimeter configuration that is being created or
    updated.
    """

    SUCCEEDED = "Succeeded"
    """SUCCEEDED."""
    CREATING = "Creating"
    """CREATING."""
    UPDATING = "Updating"
    """UPDATING."""
    DELETING = "Deleting"
    """DELETING."""
    ACCEPTED = "Accepted"
    """ACCEPTED."""
    FAILED = "Failed"
    """FAILED."""
    CANCELED = "Canceled"
    """CANCELED."""


class Odatatype(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Specifies the type of the alert criteria. Previously undocumented values might be returned."""

    MICROSOFT_AZURE_MONITOR_SINGLE_RESOURCE_MULTIPLE_METRIC_CRITERIA = (
        "Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria"
    )
    """Microsoft.Azure.Monitor.SingleResourceMultipleMetricCriteria."""
    MICROSOFT_AZURE_MONITOR_MULTIPLE_RESOURCE_MULTIPLE_METRIC_CRITERIA = (
        "Microsoft.Azure.Monitor.MultipleResourceMultipleMetricCriteria"
    )
    """Microsoft.Azure.Monitor.MultipleResourceMultipleMetricCriteria."""
    MICROSOFT_AZURE_MONITOR_WEBTEST_LOCATION_AVAILABILITY_CRITERIA = (
        "Microsoft.Azure.Monitor.WebtestLocationAvailabilityCriteria"
    )
    """Microsoft.Azure.Monitor.WebtestLocationAvailabilityCriteria."""
    MICROSOFT_AZURE_MONITOR_PROM_QL_CRITERIA = "Microsoft.Azure.Monitor.PromQLCriteria"
    """Microsoft.Azure.Monitor.PromQLCriteria."""


class OperationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of OperationType."""

    SCALE = "Scale"
    """Scale."""


class Operator(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The criteria operator. Previously undocumented values might be returned."""

    EQUALS = "Equals"
    """Equals."""
    GREATER_THAN = "GreaterThan"
    """GreaterThan."""
    GREATER_THAN_OR_EQUAL = "GreaterThanOrEqual"
    """GreaterThanOrEqual."""
    LESS_THAN = "LessThan"
    """LessThan."""
    LESS_THAN_OR_EQUAL = "LessThanOrEqual"
    """LessThanOrEqual."""


class PredictiveAutoscalePolicyScaleMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the predictive autoscale mode."""

    DISABLED = "Disabled"
    """Disabled."""
    FORECAST_ONLY = "ForecastOnly"
    """ForecastOnly."""
    ENABLED = "Enabled"
    """Enabled."""


class PrivateEndpointConnectionProvisioningState(  # pylint: disable=name-too-long
    str, Enum, metaclass=CaseInsensitiveEnumMeta
):
    """The current provisioning state."""

    SUCCEEDED = "Succeeded"
    """Connection has been provisioned."""
    CREATING = "Creating"
    """Connection is being created."""
    DELETING = "Deleting"
    """Connection is being deleted."""
    FAILED = "Failed"
    """Connection provisioning has failed."""


class PrivateEndpointServiceConnectionStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The private endpoint connection status."""

    PENDING = "Pending"
    """Connection waiting for approval or rejection."""
    APPROVED = "Approved"
    """Connection approved."""
    REJECTED = "Rejected"
    """Connection Rejected."""


class PrivateLinkScopeProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Current state of this PrivateLinkScope: whether or not is has been provisioned within the
    resource group it is defined. Users cannot change this value but are able to read from it.
    """

    SUCCEEDED = "Succeeded"
    """Succeeded."""
    FAILED = "Failed"
    """Failed."""
    DELETING = "Deleting"
    """Deleting."""
    CANCELED = "Canceled"
    """Canceled."""


class ReceiverStatus(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Indicates the status of the receiver. Receivers that are not Enabled will not receive any
    communications.
    """

    NOT_SPECIFIED = "NotSpecified"
    """NotSpecified."""
    ENABLED = "Enabled"
    """Enabled."""
    DISABLED = "Disabled"
    """Disabled."""


class RecurrenceFrequency(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the recurrence frequency. How often the schedule profile should take effect. This value must be
    Week, meaning each week will have the same set of profiles. For example, to set a daily
    schedule, set **schedule** to every day of the week. The frequency property specifies that the
    schedule is repeated weekly.
    """

    NONE = "None"
    """None."""
    SECOND = "Second"
    """Second."""
    MINUTE = "Minute"
    """Minute."""
    HOUR = "Hour"
    """Hour."""
    DAY = "Day"
    """Day."""
    WEEK = "Week"
    """Week."""
    MONTH = "Month"
    """Month."""
    YEAR = "Year"
    """Year."""


class ResourceAssociationAccessMode(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Access mode of the resource association."""

    ENFORCED = "Enforced"
    """Enforced access mode - traffic to the resource that failed access checks is blocked."""
    LEARNING = "Learning"
    """Learning access mode - traffic to the resource is enabled for analysis but not blocked."""
    AUDIT = "Audit"
    """Audit access mode - traffic to the resource that fails access checks is logged but not blocked."""


class ResultType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Type of ResultType."""

    DATA = "Data"
    """Data."""
    METADATA = "Metadata"
    """Metadata."""


class ScaleDirection(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the scale direction. Whether the scaling action increases or decreases the number of instances."""

    NONE = "None"
    """None."""
    INCREASE = "Increase"
    """Increase."""
    DECREASE = "Decrease"
    """Decrease."""


class ScaleRuleMetricDimensionOperationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the dimension operator. Only 'Equals' and 'NotEquals' are supported. 'Equals' being equal to
    any of the values. 'NotEquals' being not equal to all of the values.
    """

    EQUALS = "Equals"
    """Equals."""
    NOT_EQUALS = "NotEquals"
    """NotEquals."""


class ScaleType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """the type of action that should occur when the scale rule fires."""

    CHANGE_COUNT = "ChangeCount"
    """ChangeCount."""
    PERCENT_CHANGE_COUNT = "PercentChangeCount"
    """PercentChangeCount."""
    EXACT_COUNT = "ExactCount"
    """ExactCount."""
    SERVICE_ALLOWED_NEXT_VALUE = "ServiceAllowedNextValue"
    """ServiceAllowedNextValue."""


class ScopedResourceKind(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """The kind of scoped Azure monitor resource."""

    RESOURCE = "Resource"
    """Resource."""
    METRICS = "Metrics"
    """Metrics."""


class ScopedResourceProvisioningState(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """State of the Azure monitor resource."""

    SUCCEEDED = "Succeeded"
    """Succeeded."""
    PROVISIONING = "Provisioning"
    """Provisioning."""
    FAILED = "Failed"
    """Failed."""
    CANCELED = "Canceled"
    """Canceled."""


class Severity(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Severity of the issue."""

    WARNING = "Warning"
    """WARNING."""
    ERROR = "Error"
    """ERROR."""


class SkuTier(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """This field is required to be implemented by the Resource Provider if the service has more than
    one tier, but is not required on a PUT.
    """

    FREE = "Free"
    """The Free service tier."""
    BASIC = "Basic"
    """The Basic service tier."""
    STANDARD = "Standard"
    """The Standard service tier."""
    PREMIUM = "Premium"
    """The Premium service tier."""


class TimeAggregation(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """Aggregation type. Relevant and required only for rules of the kind LogAlert."""

    COUNT = "Count"
    """Count."""
    AVERAGE = "Average"
    """Average."""
    MINIMUM = "Minimum"
    """Minimum."""
    MAXIMUM = "Maximum"
    """Maximum."""
    TOTAL = "Total"
    """Total."""


class TimeAggregationType(str, Enum, metaclass=CaseInsensitiveEnumMeta):
    """time aggregation type. How the data that is collected should be combined over time. The default
    value is Average.
    """

    AVERAGE = "Average"
    """Average."""
    MINIMUM = "Minimum"
    """Minimum."""
    MAXIMUM = "Maximum"
    """Maximum."""
    TOTAL = "Total"
    """Total."""
    COUNT = "Count"
    """Count."""
    LAST = "Last"
    """Last."""



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import


from ._models import (  # type: ignore
    AccessModeSettings,
    AccessModeSettingsExclusion,
    AccessRule,
    AccessRuleProperties,
    AccessRulePropertiesSubscription,
    ActionDetail,
    ActionGroup,
    ActionGroupPatch,
    ActionGroupPatchBody,
    ActionGroupResource,
    ActionGroupResourceProperties,
    ActionList,
    Actions,
    ActivityLogAlertErrorResponse,
    ActivityLogAlertResource,
    AdxDestination,
    AgentSetting,
    AgentSettingsSpec,
    AlertRuleAllOfCondition,
    AlertRuleAnyOfOrLeafCondition,
    AlertRuleLeafCondition,
    AlertRulePatchObject,
    AlertRulePatchProperties,
    AlertRuleProperties,
    ApplicationInsights,
    ArmRoleReceiver,
    AutomationRunbookReceiver,
    AutoscaleErrorResponse,
    AutoscaleErrorResponseError,
    AutoscaleNotification,
    AutoscaleProfile,
    AutoscaleSetting,
    AutoscaleSettingResource,
    AutoscaleSettingResourcePatch,
    AzureAppPushReceiver,
    AzureFunctionReceiver,
    AzureMonitorMetricsDestination,
    AzureMonitorPrivateLinkScope,
    AzureMonitorPrivateLinkScopeProperties,
    BaselineMetadata,
    ColumnDefinition,
    Condition,
    ConditionFailingPeriods,
    ConfigurationAccessEndpointSpec,
    Context,
    DataCollectionEndpoint,
    DataCollectionEndpointConfigurationAccess,
    DataCollectionEndpointFailoverConfiguration,
    DataCollectionEndpointLogsIngestion,
    DataCollectionEndpointMetadata,
    DataCollectionEndpointMetricsIngestion,
    DataCollectionEndpointNetworkAcls,
    DataCollectionEndpointResource,
    DataCollectionEndpointResourceIdentity,
    DataCollectionEndpointResourceProperties,
    DataCollectionEndpointResourceSku,
    DataCollectionRule,
    DataCollectionRuleAgentSettings,
    DataCollectionRuleAssociation,
    DataCollectionRuleAssociationMetadata,
    DataCollectionRuleAssociationProxyOnlyResource,
    DataCollectionRuleAssociationProxyOnlyResourceProperties,
    DataCollectionRuleDataSources,
    DataCollectionRuleDestinations,
    DataCollectionRuleDirectDataSources,
    DataCollectionRuleEndpoints,
    DataCollectionRuleIngestionQuotas,
    DataCollectionRuleMetadata,
    DataCollectionRuleReferences,
    DataCollectionRuleResource,
    DataCollectionRuleResourceIdentity,
    DataCollectionRuleResourceProperties,
    DataCollectionRuleResourceSku,
    DataFlow,
    DataImportSources,
    DataImportSourcesEventHub,
    DataSourcesSpec,
    DataSourcesSpecDataImports,
    DestinationsSpec,
    DestinationsSpecAzureMonitorMetrics,
    Dimension,
    DirectDataSourcesSpec,
    DynamicMetricCriteria,
    DynamicPromQLCriteria,
    DynamicThresholdFailingPeriods,
    EmailNotification,
    EmailReceiver,
    EnableRequest,
    EndpointsSpec,
    EnrichmentData,
    ErrorAdditionalInfo,
    ErrorContract,
    ErrorDetail,
    ErrorDetailAdditionalInfoItem,
    ErrorDetailAutoGenerated,
    ErrorResponse,
    ErrorResponseAutoGenerated,
    ErrorResponseCommon,
    ErrorResponseCommonV2,
    ErrorResponseError,
    ErrorResponseErrorAdditionalInfoItem,
    EtwProviderDataSource,
    EventData,
    EventHubDataSource,
    EventHubDestination,
    EventHubDirectDestination,
    EventHubReceiver,
    ExtensionDataSource,
    ExtensionResource,
    FailoverConfigurationSpec,
    HttpRequestInfo,
    Identity,
    IisLogsDataSource,
    Incident,
    IncidentReceiver,
    IncidentServiceConnection,
    IngestionQuotas,
    IngestionQuotasLogs,
    ItsmReceiver,
    LocalizableString,
    LocationSpec,
    LogAnalyticsDestination,
    LogFileSettings,
    LogFileSettingsText,
    LogFileTextSettings,
    LogFilesDataSource,
    LogFilesDataSourceSettings,
    LogProfileProperties,
    LogProfileResource,
    LogProfileResourcePatch,
    LogSettings,
    LogicAppReceiver,
    LogsIngestionEndpointSpec,
    LogsQuotaSpec,
    ManagedServiceIdentity,
    Metadata,
    MetadataValue,
    Metric,
    MetricAlertAction,
    MetricAlertCriteria,
    MetricAlertErrorResponse,
    MetricAlertMultipleResourceMultipleMetricCriteria,
    MetricAlertProperties,
    MetricAlertPropertiesPatch,
    MetricAlertResource,
    MetricAlertResourcePatch,
    MetricAlertSingleResourceMultipleMetricCriteria,
    MetricAlertStatus,
    MetricAlertStatusCollection,
    MetricAlertStatusProperties,
    MetricAvailability,
    MetricBaselinesErrorResponse,
    MetricBaselinesProperties,
    MetricCriteria,
    MetricDefinition,
    MetricDimension,
    MetricNamespace,
    MetricNamespaceName,
    MetricSettings,
    MetricSingleDimension,
    MetricTrigger,
    MetricValue,
    MetricsIngestionEndpointSpec,
    MicrosoftFabricDestination,
    MonitoringAccountDestination,
    MultiMetricCriteria,
    MultiPromQLCriteria,
    NetworkRuleSet,
    NetworkSecurityPerimeter,
    NetworkSecurityPerimeterConfiguration,
    NetworkSecurityPerimeterConfigurationProperties,
    NetworkSecurityProfile,
    NotificationRequestBody,
    OperationStatus,
    OtelDataSourceResourceAttributeRouting,
    OtelLogsDataSource,
    OtelLogsDataSourceResourceAttributeRouting,
    OtelLogsDirectDataSource,
    OtelMetricsDataSource,
    OtelMetricsDataSourceResourceAttributeRouting,
    OtelMetricsDirectDataSource,
    OtelTracesDataSource,
    OtelTracesDataSourceResourceAttributeRouting,
    OtelTracesDirectDataSource,
    PerfCounterDataSource,
    PerformanceCountersOTelDataSource,
    PlatformTelemetryDataSource,
    PredictiveAutoscalePolicy,
    PredictiveResponse,
    PredictiveValue,
    PrivateEndpoint,
    PrivateEndpointConnection,
    PrivateEndpointConnectionProperties,
    PrivateLinkResource,
    PrivateLinkResourceProperties,
    PrivateLinkScopedResource,
    PrivateLinkServiceConnectionState,
    PromQLCriteria,
    PrometheusForwarderDataSource,
    ProvisioningIssue,
    ProvisioningIssueProperties,
    ProxyResource,
    QueryFailingPeriods,
    Recurrence,
    RecurrentSchedule,
    ReferencesSpec,
    ReferencesSpecEnrichmentData,
    ResolveConfiguration,
    Resource,
    ResourceAssociation,
    ResourceForUpdate,
    ResourceForUpdateIdentity,
    Response,
    RetentionPolicy,
    RuleResolveConfiguration,
    ScaleAction,
    ScaleCapacity,
    ScaleRule,
    ScaleRuleMetricDimension,
    ScheduledQueryRuleCriteria,
    ScheduledQueryRuleProperties,
    ScheduledQueryRuleResource,
    ScheduledQueryRuleResourcePatch,
    ScopedResource,
    ScopedResourceProperties,
    SenderAuthorization,
    ServiceDiagnosticSettings,
    ServiceDiagnosticSettingsResource,
    ServiceDiagnosticSettingsResourcePatch,
    SingleBaseline,
    SingleMetricBaseline,
    Sku,
    SmsReceiver,
    StaticPromQLCriteria,
    StorageBlob,
    StorageBlobDestination,
    StorageTableDestination,
    StreamDeclaration,
    SubscriptionScopeMetricDefinition,
    SubscriptionScopeMetricsRequestBodyParameters,
    SyslogDataSource,
    SystemData,
    TagsResource,
    TestNotificationDetailsResponse,
    TimeSeriesBaseline,
    TimeSeriesElement,
    TimeWindow,
    TrackedResource,
    UserAssignedIdentity,
    UserIdentityProperties,
    VoiceReceiver,
    WebhookNotification,
    WebhookReceiver,
    WebtestLocationAvailabilityCriteria,
    WindowsEventLogDataSource,
    WindowsFirewallLogsDataSource,
)

from ._enums import (  # type: ignore
    AccessMode,
    AccessRuleDirection,
    AggregationType,
    AggregationTypeEnum,
    AlertSeverity,
    BaselineSensitivity,
    ComparisonOperationType,
    ConditionOperator,
    CreatedByType,
    CriterionType,
    DimensionOperator,
    DynamicThresholdOperator,
    DynamicThresholdSensitivity,
    EventLevel,
    IdentityType,
    IncidentManagementService,
    IssueType,
    Kind,
    KnownAgentSettingName,
    KnownColumnDefinitionType,
    KnownDataCollectionEndpointProvisioningState,
    KnownDataCollectionEndpointResourceKind,
    KnownDataCollectionRuleAssociationProvisioningState,
    KnownDataCollectionRuleProvisioningState,
    KnownDataCollectionRuleResourceKind,
    KnownDataFlowStreams,
    KnownEtwProviderDataSourceLogLevel,
    KnownEtwProviderType,
    KnownExtensionDataSourceStreams,
    KnownLocationSpecProvisioningStatus,
    KnownLogFileTextSettingsRecordStartTimestampFormat,
    KnownLogFilesDataSourceFormat,
    KnownOtelLogsDataSourceStreams,
    KnownOtelLogsDirectDataSourceStreams,
    KnownOtelTracesDataSourceStreams,
    KnownOtelTracesDirectDataSourceStreams,
    KnownPerfCounterDataSourceStreams,
    KnownPerformanceCountersOTelDataSourceStreams,
    KnownPrometheusForwarderDataSourceStreams,
    KnownPublicNetworkAccessOptions,
    KnownStorageBlobLookupType,
    KnownSyslogDataSourceFacilityNames,
    KnownSyslogDataSourceLogLevels,
    KnownSyslogDataSourceStreams,
    KnownWindowsEventLogDataSourceStreams,
    KnownWindowsFirewallLogsDataSourceProfileFilter,
    ManagedServiceIdentityType,
    MetricAggregationType,
    MetricClass,
    MetricResultType,
    MetricStatisticType,
    MetricUnit,
    NamespaceClassification,
    NetworkSecurityPerimeterConfigurationProvisioningState,
    Odatatype,
    OperationType,
    Operator,
    PredictiveAutoscalePolicyScaleMode,
    PrivateEndpointConnectionProvisioningState,
    PrivateEndpointServiceConnectionStatus,
    PrivateLinkScopeProvisioningState,
    ReceiverStatus,
    RecurrenceFrequency,
    ResourceAssociationAccessMode,
    ResultType,
    ScaleDirection,
    ScaleRuleMetricDimensionOperationType,
    ScaleType,
    ScopedResourceKind,
    ScopedResourceProvisioningState,
    Severity,
    SkuTier,
    TimeAggregation,
    TimeAggregationType,
)
from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "AccessModeSettings",
    "AccessModeSettingsExclusion",
    "AccessRule",
    "AccessRuleProperties",
    "AccessRulePropertiesSubscription",
    "ActionDetail",
    "ActionGroup",
    "ActionGroupPatch",
    "ActionGroupPatchBody",
    "ActionGroupResource",
    "ActionGroupResourceProperties",
    "ActionList",
    "Actions",
    "ActivityLogAlertErrorResponse",
    "ActivityLogAlertResource",
    "AdxDestination",
    "AgentSetting",
    "AgentSettingsSpec",
    "AlertRuleAllOfCondition",
    "AlertRuleAnyOfOrLeafCondition",
    "AlertRuleLeafCondition",
    "AlertRulePatchObject",
    "AlertRulePatchProperties",
    "AlertRuleProperties",
    "ApplicationInsights",
    "ArmRoleReceiver",
    "AutomationRunbookReceiver",
    "AutoscaleErrorResponse",
    "AutoscaleErrorResponseError",
    "AutoscaleNotification",
    "AutoscaleProfile",
    "AutoscaleSetting",
    "AutoscaleSettingResource",
    "AutoscaleSettingResourcePatch",
    "AzureAppPushReceiver",
    "AzureFunctionReceiver",
    "AzureMonitorMetricsDestination",
    "AzureMonitorPrivateLinkScope",
    "AzureMonitorPrivateLinkScopeProperties",
    "BaselineMetadata",
    "ColumnDefinition",
    "Condition",
    "ConditionFailingPeriods",
    "ConfigurationAccessEndpointSpec",
    "Context",
    "DataCollectionEndpoint",
    "DataCollectionEndpointConfigurationAccess",
    "DataCollectionEndpointFailoverConfiguration",
    "DataCollectionEndpointLogsIngestion",
    "DataCollectionEndpointMetadata",
    "DataCollectionEndpointMetricsIngestion",
    "DataCollectionEndpointNetworkAcls",
    "DataCollectionEndpointResource",
    "DataCollectionEndpointResourceIdentity",
    "DataCollectionEndpointResourceProperties",
    "DataCollectionEndpointResourceSku",
    "DataCollectionRule",
    "DataCollectionRuleAgentSettings",
    "DataCollectionRuleAssociation",
    "DataCollectionRuleAssociationMetadata",
    "DataCollectionRuleAssociationProxyOnlyResource",
    "DataCollectionRuleAssociationProxyOnlyResourceProperties",
    "DataCollectionRuleDataSources",
    "DataCollectionRuleDestinations",
    "DataCollectionRuleDirectDataSources",
    "DataCollectionRuleEndpoints",
    "DataCollectionRuleIngestionQuotas",
    "DataCollectionRuleMetadata",
    "DataCollectionRuleReferences",
    "DataCollectionRuleResource",
    "DataCollectionRuleResourceIdentity",
    "DataCollectionRuleResourceProperties",
    "DataCollectionRuleResourceSku",
    "DataFlow",
    "DataImportSources",
    "DataImportSourcesEventHub",
    "DataSourcesSpec",
    "DataSourcesSpecDataImports",
    "DestinationsSpec",
    "DestinationsSpecAzureMonitorMetrics",
    "Dimension",
    "DirectDataSourcesSpec",
    "DynamicMetricCriteria",
    "DynamicPromQLCriteria",
    "DynamicThresholdFailingPeriods",
    "EmailNotification",
    "EmailReceiver",
    "EnableRequest",
    "EndpointsSpec",
    "EnrichmentData",
    "ErrorAdditionalInfo",
    "ErrorContract",
    "ErrorDetail",
    "ErrorDetailAdditionalInfoItem",
    "ErrorDetailAutoGenerated",
    "ErrorResponse",
    "ErrorResponseAutoGenerated",
    "ErrorResponseCommon",
    "ErrorResponseCommonV2",
    "ErrorResponseError",
    "ErrorResponseErrorAdditionalInfoItem",
    "EtwProviderDataSource",
    "EventData",
    "EventHubDataSource",
    "EventHubDestination",
    "EventHubDirectDestination",
    "EventHubReceiver",
    "ExtensionDataSource",
    "ExtensionResource",
    "FailoverConfigurationSpec",
    "HttpRequestInfo",
    "Identity",
    "IisLogsDataSource",
    "Incident",
    "IncidentReceiver",
    "IncidentServiceConnection",
    "IngestionQuotas",
    "IngestionQuotasLogs",
    "ItsmReceiver",
    "LocalizableString",
    "LocationSpec",
    "LogAnalyticsDestination",
    "LogFileSettings",
    "LogFileSettingsText",
    "LogFileTextSettings",
    "LogFilesDataSource",
    "LogFilesDataSourceSettings",
    "LogProfileProperties",
    "LogProfileResource",
    "LogProfileResourcePatch",
    "LogSettings",
    "LogicAppReceiver",
    "LogsIngestionEndpointSpec",
    "LogsQuotaSpec",
    "ManagedServiceIdentity",
    "Metadata",
    "MetadataValue",
    "Metric",
    "MetricAlertAction",
    "MetricAlertCriteria",
    "MetricAlertErrorResponse",
    "MetricAlertMultipleResourceMultipleMetricCriteria",
    "MetricAlertProperties",
    "MetricAlertPropertiesPatch",
    "MetricAlertResource",
    "MetricAlertResourcePatch",
    "MetricAlertSingleResourceMultipleMetricCriteria",
    "MetricAlertStatus",
    "MetricAlertStatusCollection",
    "MetricAlertStatusProperties",
    "MetricAvailability",
    "MetricBaselinesErrorResponse",
    "MetricBaselinesProperties",
    "MetricCriteria",
    "MetricDefinition",
    "MetricDimension",
    "MetricNamespace",
    "MetricNamespaceName",
    "MetricSettings",
    "MetricSingleDimension",
    "MetricTrigger",
    "MetricValue",
    "MetricsIngestionEndpointSpec",
    "MicrosoftFabricDestination",
    "MonitoringAccountDestination",
    "MultiMetricCriteria",
    "MultiPromQLCriteria",
    "NetworkRuleSet",
    "NetworkSecurityPerimeter",
    "NetworkSecurityPerimeterConfiguration",
    "NetworkSecurityPerimeterConfigurationProperties",
    "NetworkSecurityProfile",
    "NotificationRequestBody",
    "OperationStatus",
    "OtelDataSourceResourceAttributeRouting",
    "OtelLogsDataSource",
    "OtelLogsDataSourceResourceAttributeRouting",
    "OtelLogsDirectDataSource",
    "OtelMetricsDataSource",
    "OtelMetricsDataSourceResourceAttributeRouting",
    "OtelMetricsDirectDataSource",
    "OtelTracesDataSource",
    "OtelTracesDataSourceResourceAttributeRouting",
    "OtelTracesDirectDataSource",
    "PerfCounterDataSource",
    "PerformanceCountersOTelDataSource",
    "PlatformTelemetryDataSource",
    "PredictiveAutoscalePolicy",
    "PredictiveResponse",
    "PredictiveValue",
    "PrivateEndpoint",
    "PrivateEndpointConnection",
    "PrivateEndpointConnectionProperties",
    "PrivateLinkResource",
    "PrivateLinkResourceProperties",
    "PrivateLinkScopedResource",
    "PrivateLinkServiceConnectionState",
    "PromQLCriteria",
    "PrometheusForwarderDataSource",
    "ProvisioningIssue",
    "ProvisioningIssueProperties",
    "ProxyResource",
    "QueryFailingPeriods",
    "Recurrence",
    "RecurrentSchedule",
    "ReferencesSpec",
    "ReferencesSpecEnrichmentData",
    "ResolveConfiguration",
    "Resource",
    "ResourceAssociation",
    "ResourceForUpdate",
    "ResourceForUpdateIdentity",
    "Response",
    "RetentionPolicy",
    "RuleResolveConfiguration",
    "ScaleAction",
    "ScaleCapacity",
    "ScaleRule",
    "ScaleRuleMetricDimension",
    "ScheduledQueryRuleCriteria",
    "ScheduledQueryRuleProperties",
    "ScheduledQueryRuleResource",
    "ScheduledQueryRuleResourcePatch",
    "ScopedResource",
    "ScopedResourceProperties",
    "SenderAuthorization",
    "ServiceDiagnosticSettings",
    "ServiceDiagnosticSettingsResource",
    "ServiceDiagnosticSettingsResourcePatch",
    "SingleBaseline",
    "SingleMetricBaseline",
    "Sku",
    "SmsReceiver",
    "StaticPromQLCriteria",
    "StorageBlob",
    "StorageBlobDestination",
    "StorageTableDestination",
    "StreamDeclaration",
    "SubscriptionScopeMetricDefinition",
    "SubscriptionScopeMetricsRequestBodyParameters",
    "SyslogDataSource",
    "SystemData",
    "TagsResource",
    "TestNotificationDetailsResponse",
    "TimeSeriesBaseline",
    "TimeSeriesElement",
    "TimeWindow",
    "TrackedResource",
    "UserAssignedIdentity",
    "UserIdentityProperties",
    "VoiceReceiver",
    "WebhookNotification",
    "WebhookReceiver",
    "WebtestLocationAvailabilityCriteria",
    "WindowsEventLogDataSource",
    "WindowsFirewallLogsDataSource",
    "AccessMode",
    "AccessRuleDirection",
    "AggregationType",
    "AggregationTypeEnum",
    "AlertSeverity",
    "BaselineSensitivity",
    "ComparisonOperationType",
    "ConditionOperator",
    "CreatedByType",
    "CriterionType",
    "DimensionOperator",
    "DynamicThresholdOperator",
    "DynamicThresholdSensitivity",
    "EventLevel",
    "IdentityType",
    "IncidentManagementService",
    "IssueType",
    "Kind",
    "KnownAgentSettingName",
    "KnownColumnDefinitionType",
    "KnownDataCollectionEndpointProvisioningState",
    "KnownDataCollectionEndpointResourceKind",
    "KnownDataCollectionRuleAssociationProvisioningState",
    "KnownDataCollectionRuleProvisioningState",
    "KnownDataCollectionRuleResourceKind",
    "KnownDataFlowStreams",
    "KnownEtwProviderDataSourceLogLevel",
    "KnownEtwProviderType",
    "KnownExtensionDataSourceStreams",
    "KnownLocationSpecProvisioningStatus",
    "KnownLogFileTextSettingsRecordStartTimestampFormat",
    "KnownLogFilesDataSourceFormat",
    "KnownOtelLogsDataSourceStreams",
    "KnownOtelLogsDirectDataSourceStreams",
    "KnownOtelTracesDataSourceStreams",
    "KnownOtelTracesDirectDataSourceStreams",
    "KnownPerfCounterDataSourceStreams",
    "KnownPerformanceCountersOTelDataSourceStreams",
    "KnownPrometheusForwarderDataSourceStreams",
    "KnownPublicNetworkAccessOptions",
    "KnownStorageBlobLookupType",
    "KnownSyslogDataSourceFacilityNames",
    "KnownSyslogDataSourceLogLevels",
    "KnownSyslogDataSourceStreams",
    "KnownWindowsEventLogDataSourceStreams",
    "KnownWindowsFirewallLogsDataSourceProfileFilter",
    "ManagedServiceIdentityType",
    "MetricAggregationType",
    "MetricClass",
    "MetricResultType",
    "MetricStatisticType",
    "MetricUnit",
    "NamespaceClassification",
    "NetworkSecurityPerimeterConfigurationProvisioningState",
    "Odatatype",
    "OperationType",
    "Operator",
    "PredictiveAutoscalePolicyScaleMode",
    "PrivateEndpointConnectionProvisioningState",
    "PrivateEndpointServiceConnectionStatus",
    "PrivateLinkScopeProvisioningState",
    "ReceiverStatus",
    "RecurrenceFrequency",
    "ResourceAssociationAccessMode",
    "ResultType",
    "ScaleDirection",
    "ScaleRuleMetricDimensionOperationType",
    "ScaleType",
    "ScopedResourceKind",
    "ScopedResourceProvisioningState",
    "Severity",
    "SkuTier",
    "TimeAggregation",
    "TimeAggregationType",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()



# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for license information.
# Code generated by Microsoft (R) Python Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is regenerated.
# --------------------------------------------------------------------------
# pylint: disable=wrong-import-position

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ._patch import *  # pylint: disable=unused-wildcard-import

from ._operations import PrivateLinkResourcesOperations  # type: ignore
from ._operations import PrivateEndpointConnectionsOperations  # type: ignore
from ._operations import DataCollectionEndpointsOperations  # type: ignore
from ._operations import ScheduledQueryRuleOperations  # type: ignore
from ._operations import DataCollectionRuleAssociationsOperations  # type: ignore
from ._operations import DataCollectionRulesOperations  # type: ignore
from ._operations import PrivateLinkScopesOperations  # type: ignore
from ._operations import PrivateLinkScopedResourcesOperations  # type: ignore
from ._operations import PrivateLinkScopeOperationStatusOperations  # type: ignore
from ._operations import AutoscaleSettingsOperations  # type: ignore
from ._operations import PredictiveMetricOperations  # type: ignore
from ._operations import ActivityLogsOperations  # type: ignore
from ._operations import EventCategoriesOperations  # type: ignore
from ._operations import TenantActivityLogsOperations  # type: ignore
from ._operations import MetricDefinitionsOperations  # type: ignore
from ._operations import MetricNamespacesOperations  # type: ignore
from ._operations import MetricsOperations  # type: ignore
from ._operations import ServiceDiagnosticSettingsOperations  # type: ignore
from ._operations import AlertRuleIncidentsOperations  # type: ignore
from ._operations import LogProfilesOperations  # type: ignore
from ._operations import ActivityLogAlertsOperations  # type: ignore
from ._operations import MetricAlertsOperations  # type: ignore
from ._operations import MetricAlertsStatusOperations  # type: ignore
from ._operations import ScheduledQueryRulesOperations  # type: ignore
from ._operations import BaselinesOperations  # type: ignore
from ._operations import ActionGroupsOperations  # type: ignore

from ._patch import __all__ as _patch_all
from ._patch import *
from ._patch import patch_sdk as _patch_sdk

__all__ = [
    "PrivateLinkResourcesOperations",
    "PrivateEndpointConnectionsOperations",
    "DataCollectionEndpointsOperations",
    "ScheduledQueryRuleOperations",
    "DataCollectionRuleAssociationsOperations",
    "DataCollectionRulesOperations",
    "PrivateLinkScopesOperations",
    "PrivateLinkScopedResourcesOperations",
    "PrivateLinkScopeOperationStatusOperations",
    "AutoscaleSettingsOperations",
    "PredictiveMetricOperations",
    "ActivityLogsOperations",
    "EventCategoriesOperations",
    "TenantActivityLogsOperations",
    "MetricDefinitionsOperations",
    "MetricNamespacesOperations",
    "MetricsOperations",
    "ServiceDiagnosticSettingsOperations",
    "AlertRuleIncidentsOperations",
    "LogProfilesOperations",
    "ActivityLogAlertsOperations",
    "MetricAlertsOperations",
    "MetricAlertsStatusOperations",
    "ScheduledQueryRulesOperations",
    "BaselinesOperations",
    "ActionGroupsOperations",
]
__all__.extend([p for p in _patch_all if p not in __all__])  # pyright: ignore
_patch_sdk()
